@@ -54,6 +54,7 @@ class BeautifierFlags:
         self.in_case = False
         self.in_case_statement = False
         self.case_body = False
+        self.case_block = False
         self.indentation_level = 0
         self.alignment = 0
         self.line_indent_level = 0
@@ -728,10 +729,13 @@ class Beautifier:
         ):
             # We don't support TypeScript,but we didn't break it for a very long time.
             # We'll try to keep not breaking it.
-            if self._last_last_text not in ["class", "interface"]:
-                self.set_mode(MODE.ObjectLiteral)
-            else:
+            if self._last_last_text in [
+                "class",
+                "interface",
+            ] and second_token.text not in [":", ","]:
                 self.set_mode(MODE.BlockStatement)
+            else:
+                self.set_mode(MODE.ObjectLiteral)
         elif (
             self._flags.last_token.type == TOKEN.OPERATOR
             and self._flags.last_token.text == "=>"
@@ -874,7 +878,10 @@ class Beautifier:
                 and self._flags.mode != MODE.ObjectLiteral
             ):
                 current_token.type = TOKEN.WORD
-            elif current_token.text == "import" and self._tokens.peek().text == "(":
+            elif current_token.text == "import" and self._tokens.peek().text in [
+                "(",
+                ".",
+            ]:
                 current_token.type = TOKEN.WORD
             elif current_token.text in ["as", "from"] and not self._flags.import_block:
                 current_token.type = TOKEN.WORD
@@ -945,7 +952,7 @@ class Beautifier:
             current_token, ["case", "default"]
         ):
             self.print_newline()
-            if self._flags.last_token.type != TOKEN.END_BLOCK and (
+            if (not self._flags.case_block) and (
                 self._flags.case_body or self._options.jslint_happy
             ):
                 self.deindent()
@@ -1331,8 +1338,10 @@ class Beautifier:
             if self._tokens.peek().type != TOKEN.START_BLOCK:
                 self.indent()
                 self.print_newline()
+                self._flags.case_block = False
             else:
                 self._output.space_before_token = True
+                self._flags.case_block = True
 
             return
 
@@ -1436,7 +1445,9 @@ class Beautifier:
             # if there is a newline between -- or ++ and anything else we
             # should preserve it.
             if current_token.newlines and (
-                current_token.text == "--" or current_token.text == "++"
+                current_token.text == "--"
+                or current_token.text == "++"
+                or current_token.text == "~"
             ):
                 self.print_newline(preserve_statement_flags=True)
 
@@ -1457,16 +1468,12 @@ class Beautifier:
             elif self._flags.last_token.type == TOKEN.OPERATOR:
                 # a++ + ++b
                 # a - -b
-                space_before = (
-                    current_token.text
-                    in [
-                        "--",
-                        "-",
-                        "++",
-                        "+",
-                    ]
-                    and self._flags.last_token.text in ["--", "-", "++", "+"]
-                )
+                space_before = current_token.text in [
+                    "--",
+                    "-",
+                    "++",
+                    "+",
+                ] and self._flags.last_token.text in ["--", "-", "++", "+"]
                 # + and - are not unary when preceeded by -- or ++ operator
                 # a-- + b
                 # a * +b
